@@ -3,17 +3,19 @@ from pathlib import Path
 from datetime import datetime
 
 class logger:
-    def __init__(self, filename=None, max_lines=10000):
-        if not filename:
-            filename = Path(sys.argv[0]).stem + '.txt'
+    def __init__(self, log_filepath=None, max_lines=10000):
+        filename = Path(sys.argv[0]).stem
         self.filename = filename
+        if not log_filepath:
+            log_filepath = f'{os.getcwd()}/{filename}.txt'
+        self.log_filepath = log_filepath
         self.max_lines = max_lines
 
         logger = logging.getLogger(__name__)
         logger.setLevel(logging.DEBUG)
 
-        log_file = logging.FileHandler(filename, encoding='utf-8')
-        log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%H:%M:%S')
+        log_file = logging.FileHandler(log_filepath, encoding='utf-8')
+        log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
         log_file.setFormatter(log_format)
         logger.addHandler(log_file)
         self.log_file = log_file
@@ -21,6 +23,10 @@ class logger:
         coloredlogs.install(level=logging.INFO, logger=logger, fmt='%(message)s')
         self.logger = logger
 
+        self.log()
+        self.log('Starting', filename)
+        self.log()
+
     def log(self, *items, level='info'):
         message = ''
         for item in items:
@@ -54,14 +60,19 @@ class logger:
             self.logger.warning(message)
 
         if not message:
-            log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%H:%M:%S')
+            log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
             self.log_file.setFormatter(log_format)
 
-        log_file = open(self.filename, 'r+').read()
+        log_file = open(self.log_filepath, 'r+').read()
         number_of_lines = len(log_file.splitlines())
         if number_of_lines > self.max_lines:
             self.logger.info('Resetting log file')
             self.log_file.close()
+            log_file = logging.FileHandler(self.log_filepath, mode='w', encoding='utf-8')
+            log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
+            log_file.setFormatter(log_format)
+            self.logger.addHandler(log_file)
+            self.log_file = log_file
     
     def error(self, *items):
         self.log(*items, level='error')
@@ -76,13 +87,17 @@ class logger:
         self.log(*items, level='warning')
     
     def current_time(self, *items, level='info'):
-        coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(asctime)s.%(msecs)03d: %(message)s', datefmt='%H:%M:%S') # Add curent time to printed log output format
+        coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(asctime)s.%(msecs)03d: %(message)s', datefmt='%H:%M:%S') # Add current time to printed log output format
         self.log(*items, level=level)
         coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(message)s') # Reset to default log format
 
+    # def __del__(self):
+    #     self.log('Exiting', self.filename)
+    #     self.log()
+
 class printr:
     '''printr'''
-    def __init__(self, *items, same_line=False, current_time=False, level='info'):
+    def __init__(self, *items, same_line=False, current_time=False, check_for_log=True, level='info'):
         if len(items) == 1:
             message = items[0]
             if isinstance(message, dict) or isinstance(message, list):
@@ -109,21 +124,24 @@ class printr:
             print(message, end='')
             print('\r', end='')
         else:
-            logger = logging.getLogger()
-            if logger.level != 30:
-                if level == 'debug':
-                    logger.debug(message)
-                elif level == 'error':
-                    logger.error(message)
-                else:
-                    logger.info(message)
-            elif level != 'debug':
+            if not check_for_log:
                 print(message)
+            else:
+                logger = logging.getLogger()
+                if logger.level != 30:
+                    if level == 'debug':
+                        logger.debug(message)
+                    elif level == 'error':
+                        logger.error(message)
+                    else:
+                        logger.info(message)
+                elif level != 'debug':
+                    print(message)
 
 class current_time:
-    def __init__(self, *items, same_line=False):
-        printr(*items, same_line=same_line, current_time=True)
+    def __init__(self, *items, same_line=False, check_for_log=True):
+        printr(*items, same_line=same_line, current_time=True, check_for_log=check_for_log)
 
 class same_line:
-    def __init__(self, *items, current_time=False):
-        printr(*items, same_line=same_line, current_time=current_time)
\ No newline at end of file
+    def __init__(self, *items, current_time=False, check_for_log=True):
+        printr(*items, same_line=same_line, current_time=current_time, check_for_log=check_for_log)
\ No newline at end of file
